package nl.kallestruik.dchat.commands;

import nl.kallestruik.dchat.Util;
import nl.kallestruik.dchat.managers.PlayerDataManager;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import org.bukkit.command.TabCompleter;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.Arrays;
import java.util.List;
import java.util.UUID;
import java.util.stream.Collectors;

public class CommandChatsettings implements CommandExecutor, TabCompleter {
    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label, @NotNull String[] args) {
        if (args.length < 2)
            return false;

        UUID uuid = Util.getUUID(sender);

        switch (args[0]) {
            case "pingSound":
                if (PlayerDataManager.changePingSoundSettingForUUID(uuid, args[1]))
                    sender.sendMessage("Changed ping sound to: " + args[1]);
                else
                    sender.sendMessage("That is not a valid value!");
                break;
            case "nameColor":
                if (PlayerDataManager.changeNameColorSettingForUUID(uuid, args[1]))
                    sender.sendMessage("Changed name color to: " + args[1]);
                else
                    sender.sendMessage("That is not a valid value!");
                break;
            case "prefixColor":
                if (PlayerDataManager.changePrefixColorSettingForUUID(uuid, args[1]))
                    sender.sendMessage("Changed prefix color to: " + args[1]);
                else
                    sender.sendMessage("That is not a valid value!");
                break;
            case "prefix":
                if (PlayerDataManager.changePrefixSettingForUUID(uuid, String.join(" ", Arrays.copyOfRange(args, 1, args.length))))
                    sender.sendMessage("Changed prefix to: " + args[1]);
                else
                    sender.sendMessage("That is not a valid value!");
                break;
        }

        return true;
    }

    @Override
    public @Nullable List<String> onTabComplete(@NotNull CommandSender sender, @NotNull Command command, @NotNull String alias, @NotNull String[] args) {
        if (args.length == 1)
            return List.of("pingSound", "nameColor", "prefixColor", "prefix").stream().filter((option) -> option.startsWith(args[0])).collect(Collectors.toList());

        if (args.length == 2)
            switch (args[0]) {
                case "pingSound":
                    return List.of("Yes", "No");
                case "nameColor":
                case "prefixColor":
                    return List.of("#");
            }

        return null;
    }
}
