package nl.kallestruik.dchat.managers;

import net.kyori.adventure.text.Component;
import net.kyori.adventure.text.TextComponent;
import net.kyori.adventure.text.event.ClickEvent;
import net.kyori.adventure.text.format.TextColor;
import nl.kallestruik.dchat.Config;
import nl.kallestruik.dchat.types.Emote;
import org.bukkit.Bukkit;
import org.bukkit.Sound;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;
import org.bukkit.inventory.ItemStack;

import java.util.UUID;

public class ChatManager {

    public static void sendMessage(CommandSender sender, Component message) {
        message = mentions(message);
        message = item(message, sender);
        message = emoji(message);

        message = populateTemplate(message, sender);
        Bukkit.broadcast(message, "dchat.receive");
        Bukkit.getConsoleSender().sendMessage(message);
    }

    private static Component populateTemplate(Component message, CommandSender sender) {
        UUID uuid = sender instanceof Player ? ((Player) sender).getUniqueId() : new UUID(0,0); // Console get UUID 0

        return Config.CHAT_FORMAT
                .replaceText((builder) -> builder.match("%PREFIX%")
                        .replacement(PlayerDataManager.getPrefixForUUID(uuid))
                        .times(1))
                .replaceText((builder) -> builder.match("%USERNAME%")
                        .replacement(Component.text(sender.getName()).color(PlayerDataManager.getColorForUUID(uuid)))
                        .times(1))
                .replaceText((builder) -> builder.match("%MESSAGE%")
                        .replacement(message)
                        .times(1));
    }

    private static Component mentions(Component message) {
        for (Player player : Bukkit.getOnlinePlayers()) {
            if (!((TextComponent)message).content().matches(".*@" + player.getName() + "\\b.*"))
                continue;

            if (PlayerDataManager.getSettingsForUUID(player.getUniqueId()).isPingSound())
                player.playSound(player.getLocation(), Sound.ENTITY_EXPERIENCE_ORB_PICKUP, 1, 1);

            message = message.replaceText((builder) -> builder
                    .match("\\@" + player.getName() + "\\b")
                    .replacement(
                            Component.text("@" + player.getName())
                                    .hoverEvent(player.asHoverEvent())
                                    .clickEvent(ClickEvent.suggestCommand("/msg " + player.getName() + " "))
                                    .color(PlayerDataManager.getColorForUUID(player.getUniqueId()))
                    ).times(1));
        }
        return message;
    }

    private static Component emoji(Component message) {
        String messageText = ((TextComponent)message).content();

        if (!messageText.contains(":"))
            return message;

        String[] parts = messageText.split(":");
        for (int i = 1; i < parts.length; i++) {
            String emojiName = parts[i].split(":")[0];
            Emote emote = EmojiManager.getExact(emojiName);
            if (emote != null)
                message = message.replaceText((builder) -> builder
                        .match(":" + emojiName + ":")
                        .replacement(Component.text(emote.getSymbol())));
        }

        return message;

    }

    private static Component item(Component message, CommandSender sender) {
        if (!(sender instanceof Player))
            return message;

        Player player = (Player) sender;
        ItemStack item = player.getInventory().getItemInMainHand();

        Component itemName = Component.text(item.getI18NDisplayName());
        if (item.hasItemMeta() && item.getItemMeta().hasDisplayName())
            itemName = item.getItemMeta().displayName();

        if (itemName == null)
            return message;

        //TODO: Better item color?
        Component toShow = Component.text("[").append(itemName).append(Component.text("]")).color(TextColor.color(0xC3C3));

        return message.replaceText((
                builder -> builder.match("\\[item\\]")
                        .replacement(toShow.hoverEvent(item.asHoverEvent())))
        );
    }
}
