package nl.kallestruik.dchat.managers;

import com.google.common.reflect.TypeToken;
import nl.kallestruik.dchat.Config;
import nl.kallestruik.dchat.DChat;
import nl.kallestruik.dchat.Util;
import nl.kallestruik.dchat.types.Emote;

import java.io.*;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

public class EmojiManager {
    private static final HashMap<String, Emote> emojiMap = new HashMap<>();
//    static {
//        emojiMap.put("ban_dream", new Emoji("ban_dream", "\ue000", "Just ban him already!"));
//        emojiMap.put("wood_pickaxe", new Emoji("wood_pickaxe", "\ue001", "The most basic pickaxe."));
//        emojiMap.put("wood_shovel", new Emoji("wood_shovel", "\ue002", "The most basic shovel."));
//        emojiMap.put("wood_axe", new Emoji("wood_axe", "\ue003", "The most basic axe."));
//        emojiMap.put("wood_hoe", new Emoji("wood_hoe", "\ue004", "The most basic hoe."));
//    }

    public static Set<Map.Entry<String, Emote>> findMatches(String search) {
        return emojiMap.entrySet().stream().filter((entry) -> entry.getKey().contains(search)).collect(Collectors.toSet());
    }

    public static Emote getExact(String emojiName) {
        return emojiMap.getOrDefault(emojiName, null);
    }

    public static void loadEmotesFromDisk() {
        File emoteDB = new File(DChat.instance.getDataFolder(), "emotedb.json");
        if (!emoteDB.exists()) {
            DChat.logger.warning("Could not load emotes from disk. You should run /cadmin update-emotes");
            return;
        }

        try {
            List<Emote> emotes = DChat.gson.fromJson(new FileReader(emoteDB), new TypeToken<List<Emote>>() {}.getType());
            emotes.forEach((emote) -> {
                emojiMap.put(emote.getName(), emote);
            });
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        }
    }

    public static void updateEmotes() {
        String emoteDBJson = Util.httpGET(Config.EMOTE_DB_URL);
        File emoteDB = new File(DChat.instance.getDataFolder(), "emotedb.json");

        try (FileWriter writer = new FileWriter(emoteDB)) {
            writer.write(emoteDBJson);
        } catch (IOException e) {
            e.printStackTrace();
        }

        loadEmotesFromDisk();
    }
}
