package nl.kallestruik.dchat.managers;

import net.kyori.adventure.text.Component;
import net.kyori.adventure.text.format.TextColor;
import nl.kallestruik.dchat.DChat;
import nl.kallestruik.dchat.types.PlayerSettings;

import java.io.File;
import java.util.HashMap;
import java.util.Locale;
import java.util.UUID;

public class PlayerDataManager {
    private static final HashMap<UUID, PlayerSettings> playerSettings = new HashMap<>();

    public static Component getPrefixForUUID(UUID uuid) {
        PlayerSettings settings = getSettingsForUUID(uuid);

        return Component.text(settings.getPrefix()).color(TextColor.color(settings.getPrefixColor()));
    }

    public static TextColor getColorForUUID(UUID uuid) {
        PlayerSettings settings = getSettingsForUUID(uuid);

        return settings.getNameColor();
    }

    public static void loadPlayerData(UUID uuid) {
        File dataFile = new File(DChat.instance.getDataFolder(), "/data/" + uuid.toString() + ".json");
        PlayerSettings settings = PlayerSettings.loadFromFile(dataFile);
        if (settings == null)
            return;

        playerSettings.put(uuid, settings);
    }

    public static PlayerSettings getSettingsForUUID(UUID uuid) {
        return playerSettings.getOrDefault(uuid, new PlayerSettings(uuid));
    }

    public static boolean changePingSoundSettingForUUID(UUID uuid, String value) {
        boolean enablePingSound;
        switch (value.toLowerCase(Locale.ROOT)) {
            case "true":
            case "yes":
            case "enable":
                enablePingSound = true;
                break;
            case "false":
            case "no":
            case "disable":
                enablePingSound = false;
                break;
            default:
                return false;
        }

        PlayerSettings settings = playerSettings.getOrDefault(uuid, new PlayerSettings(uuid));
        settings.setPingSound(enablePingSound);
        playerSettings.put(uuid, settings);
        settings.save();
        return true;
    }

    public static boolean changeNameColorSettingForUUID(UUID uuid, String value) {
        if (!value.startsWith("#"))
            value = "#" + value;

        TextColor nameColor = TextColor.fromCSSHexString(value);
        if (nameColor == null)
            return false;

        PlayerSettings settings = playerSettings.getOrDefault(uuid, new PlayerSettings(uuid));
        settings.setNameColor(nameColor);
        playerSettings.put(uuid, settings);
        settings.save();
        return true;
    }

    public static boolean changePrefixColorSettingForUUID(UUID uuid, String value) {
        if (!value.startsWith("#"))
            value = "#" + value;

        TextColor prefixColor = TextColor.fromCSSHexString(value);
        if (prefixColor == null)
            return false;

        PlayerSettings settings = playerSettings.getOrDefault(uuid, new PlayerSettings(uuid));
        settings.setPrefixColor(prefixColor);
        playerSettings.put(uuid, settings);
        settings.save();
        return true;
    }

    public static boolean changePrefixSettingForUUID(UUID uuid, String value) {
        if (value == null || value.isEmpty())
            return false;

        PlayerSettings settings = playerSettings.getOrDefault(uuid, new PlayerSettings(uuid));
        settings.setPrefix(value);
        playerSettings.put(uuid, settings);
        settings.save();
        return true;
    }
}
