package nl.kallestruik.dchat.types;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import net.kyori.adventure.text.format.TextColor;
import nl.kallestruik.dchat.DChat;

import java.io.*;
import java.util.UUID;

@Data
@AllArgsConstructor
@NoArgsConstructor
public class PlayerSettings {
    private UUID owner;
    private boolean pingSound = true;
    private TextColor nameColor = TextColor.color(0xFFFFFF);
    private TextColor prefixColor = TextColor.color(0xFFFFFF);
    private String prefix = "default";

    public PlayerSettings(UUID owner) {
        this.owner = owner;
    }

    public static PlayerSettings loadFromFile(File dataFile) {
        if (!dataFile.exists()) {
            return null;
        }

        try {
            return DChat.gson.fromJson(new FileReader(dataFile), PlayerSettings.class);
        } catch (FileNotFoundException e) {
            DChat.logger.warning("Could not load player data file: " + dataFile.getName());
        }

        return null;
    }

    public void save() {
        File dataFile = new File(DChat.instance.getDataFolder(), "/data/" + owner.toString() + ".json");
        try (FileWriter writer = new FileWriter(dataFile)) {
            writer.write(DChat.gson.toJson(this));
        } catch (IOException e) {
            e.printStackTrace();
        }
    }
}
